==> ejc-credentials-impl-3.0.0-20220511.085154-8-sources.jar: com/ejianc/certify/bean/CertifTypeEntity.java <==
package com.ejianc.certify.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 证件类别
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_certiftype")
public class CertifTypeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pk_parent")
    private String pkParent; // 父节点pk
    @TableField(value="pk_group")
    private String pkGroup; // 集团
    @TableField(value="pk_org")
    private Long pkOrg; // 组织
    @TableField(value="vcode")
    private String vcode; // 编码
    @TableField(value="vname")
    private String vname; // 名称
    @TableField(value="innercode")
    private String innercode; // 内部编码
    @TableField(value="enablestate")
    private Integer enablestate; // 0-未启用 1-已启用 2-已停用
    @TableField(value="typeattribute")
    private String typeattribute; // 证照类别属性
    @TableField(value="specialtype")
    private String specialtype; // 特殊证照类别
    @TableField(value="jfrule")
    private String jfrule; // 持证补贴计费规则（0-不计费 1-独自生效 2-关联证件生效 ）
    @TableField(value="relate_certiftype")
    private String relateCertiftype; // 关联证照类别
    @TableField(value="row_num")
    private Integer rowNum; // 排序
    @TableField(value="has_effective_date")
    private String hasEffectiveDate; // 是否存在证件有效期预警 0-是 1-否 
    @TableField(value="warn_time")
    private Integer warnTime; // 预警提醒时长（月）
    @TableField(value="advance_time")
    private Integer advanceTime; // 失效提前预警时间（月）
    @TableField(value="disposable")
    private String disposable; // 是否一次性奖励, 0-是  1-否
    @TableField(value="dispos_amt")
    private BigDecimal disposAmt; // 一次性奖励额
    @TableField(value="yzdybt_amt")
    private String yzdybtAmt; // 一证多用补贴额
    @TableField(value="nbasicbenefit")
    private BigDecimal nbasicbenefit; // 基本补贴额
    @TableField(value="nusebenefit")
    private BigDecimal nusebenefit; // 使用补贴额
    @TableField(value="ncheckbenefit")
    private BigDecimal ncheckbenefit; // 迎检出场补贴额
    @TableField(value="nyzbenefit")
    private BigDecimal nyzbenefit; // 造价工程师用印补贴额
    @TableField(value="gwrule")
    private String gwrule; // 岗位补贴计算规则
    @TableField(value="ngwbenefit")
    private String ngwbenefit; // 岗位补贴额
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; // 
    @TableField(value="ts")
    private Date ts; // 时间戳
    
    
    

    public String getPkParent() {
        return pkParent;
    }

    public void setPkParent(String pkParent) {
        this.pkParent = pkParent;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }
    public String getVcode() {
        return vcode;
    }

    public void setVcode(String vcode) {
        this.vcode = vcode;
    }
    public String getVname() {
        return vname;
    }

    public void setVname(String vname) {
        this.vname = vname;
    }
    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }
    public Integer getEnablestate() {
        return enablestate;
    }

    public void setEnablestate(Integer enablestate) {
        this.enablestate = enablestate;
    }
    public String getTypeattribute() {
        return typeattribute;
    }

    public void setTypeattribute(String typeattribute) {
        this.typeattribute = typeattribute;
    }
    public String getSpecialtype() {
        return specialtype;
    }

    public void setSpecialtype(String specialtype) {
        this.specialtype = specialtype;
    }
    public String getJfrule() {
        return jfrule;
    }

    public void setJfrule(String jfrule) {
        this.jfrule = jfrule;
    }
    public String getRelateCertiftype() {
        return relateCertiftype;
    }

    public void setRelateCertiftype(String relateCertiftype) {
        this.relateCertiftype = relateCertiftype;
    }
    public Integer getRowNum() {
        return rowNum;
    }

    public void setRowNum(Integer rowNum) {
        this.rowNum = rowNum;
    }
    public String getHasEffectiveDate() {
        return hasEffectiveDate;
    }

    public void setHasEffectiveDate(String hasEffectiveDate) {
        this.hasEffectiveDate = hasEffectiveDate;
    }
    public Integer getWarnTime() {
        return warnTime;
    }

    public void setWarnTime(Integer warnTime) {
        this.warnTime = warnTime;
    }
    public Integer getAdvanceTime() {
        return advanceTime;
    }

    public void setAdvanceTime(Integer advanceTime) {
        this.advanceTime = advanceTime;
    }
    public String getDisposable() {
        return disposable;
    }

    public void setDisposable(String disposable) {
        this.disposable = disposable;
    }
    public BigDecimal getDisposAmt() {
        return disposAmt;
    }

    public void setDisposAmt(BigDecimal disposAmt) {
        this.disposAmt = disposAmt;
    }
    public String getYzdybtAmt() {
        return yzdybtAmt;
    }

    public void setYzdybtAmt(String yzdybtAmt) {
        this.yzdybtAmt = yzdybtAmt;
    }
    public BigDecimal getNbasicbenefit() {
        return nbasicbenefit;
    }

    public void setNbasicbenefit(BigDecimal nbasicbenefit) {
        this.nbasicbenefit = nbasicbenefit;
    }
    public BigDecimal getNusebenefit() {
        return nusebenefit;
    }

    public void setNusebenefit(BigDecimal nusebenefit) {
        this.nusebenefit = nusebenefit;
    }
    public BigDecimal getNcheckbenefit() {
        return ncheckbenefit;
    }

    public void setNcheckbenefit(BigDecimal ncheckbenefit) {
        this.ncheckbenefit = ncheckbenefit;
    }
    public BigDecimal getNyzbenefit() {
        return nyzbenefit;
    }

    public void setNyzbenefit(BigDecimal nyzbenefit) {
        this.nyzbenefit = nyzbenefit;
    }
    public String getGwrule() {
        return gwrule;
    }

    public void setGwrule(String gwrule) {
        this.gwrule = gwrule;
    }
    public String getNgwbenefit() {
        return ngwbenefit;
    }

    public void setNgwbenefit(String ngwbenefit) {
        this.ngwbenefit = ngwbenefit;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220518.110548-20-sources.jar: com/ejianc/certify/bean/CertifTypeEntity.java <==
package com.ejianc.certify.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 证件类别
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_certiftype")
public class CertifTypeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pk_parent")
    private String pkParent; // 父节点pk
    @TableField(value="pk_group")
    private String pkGroup; // 集团
    @TableField(value="pk_org")
    private Long pkOrg; // 组织
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="name")
    private String name; // 名称
    @TableField(value="innercode")
    private String innercode; // 内部编码
    @TableField(value="enablestate")
    private Integer enablestate; // 0-未启用 1-已启用 2-已停用
    @TableField(value="typeattribute")
    private String typeattribute; // 证照类别属性
    @TableField(value="specialtype")
    private String specialtype; // 特殊证照类别
    @TableField(value="jfrule")
    private String jfrule; // 持证补贴计费规则（0-不计费 1-独自生效 2-关联证件生效 ）
    @TableField(value="relate_certiftype")
    private String relateCertiftype; // 关联证照类别
    @TableField(value="row_num")
    private Integer rowNum; // 排序
    @TableField(value="has_effective_date")
    private String hasEffectiveDate; // 是否存在证件有效期预警 0-是 1-否 
    @TableField(value="warn_time")
    private Integer warnTime; // 预警提醒时长（月）
    @TableField(value="advance_time")
    private Integer advanceTime; // 失效提前预警时间（月）
    @TableField(value="disposable")
    private String disposable; // 是否一次性奖励, 0-是  1-否
    @TableField(value="dispos_amt")
    private BigDecimal disposAmt; // 一次性奖励额
    @TableField(value="yzdybt_amt")
    private String yzdybtAmt; // 一证多用补贴额
    @TableField(value="nbasicbenefit")
    private BigDecimal nbasicbenefit; // 基本补贴额
    @TableField(value="nusebenefit")
    private BigDecimal nusebenefit; // 使用补贴额
    @TableField(value="ncheckbenefit")
    private BigDecimal ncheckbenefit; // 迎检出场补贴额
    @TableField(value="nyzbenefit")
    private BigDecimal nyzbenefit; // 造价工程师用印补贴额
    @TableField(value="gwrule")
    private String gwrule; // 岗位补贴计算规则
    @TableField(value="ngwbenefit")
    private String ngwbenefit; // 岗位补贴额
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; // 
    @TableField(value="ts")
    private Date ts; // 时间戳
    
    
    

    public String getPkParent() {
        return pkParent;
    }

    public void setPkParent(String pkParent) {
        this.pkParent = pkParent;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }
    public Integer getEnablestate() {
        return enablestate;
    }

    public void setEnablestate(Integer enablestate) {
        this.enablestate = enablestate;
    }
    public String getTypeattribute() {
        return typeattribute;
    }

    public void setTypeattribute(String typeattribute) {
        this.typeattribute = typeattribute;
    }
    public String getSpecialtype() {
        return specialtype;
    }

    public void setSpecialtype(String specialtype) {
        this.specialtype = specialtype;
    }
    public String getJfrule() {
        return jfrule;
    }

    public void setJfrule(String jfrule) {
        this.jfrule = jfrule;
    }
    public String getRelateCertiftype() {
        return relateCertiftype;
    }

    public void setRelateCertiftype(String relateCertiftype) {
        this.relateCertiftype = relateCertiftype;
    }
    public Integer getRowNum() {
        return rowNum;
    }

    public void setRowNum(Integer rowNum) {
        this.rowNum = rowNum;
    }
    public String getHasEffectiveDate() {
        return hasEffectiveDate;
    }

    public void setHasEffectiveDate(String hasEffectiveDate) {
        this.hasEffectiveDate = hasEffectiveDate;
    }
    public Integer getWarnTime() {
        return warnTime;
    }

    public void setWarnTime(Integer warnTime) {
        this.warnTime = warnTime;
    }
    public Integer getAdvanceTime() {
        return advanceTime;
    }

    public void setAdvanceTime(Integer advanceTime) {
        this.advanceTime = advanceTime;
    }
    public String getDisposable() {
        return disposable;
    }

    public void setDisposable(String disposable) {
        this.disposable = disposable;
    }
    public BigDecimal getDisposAmt() {
        return disposAmt;
    }

    public void setDisposAmt(BigDecimal disposAmt) {
        this.disposAmt = disposAmt;
    }
    public String getYzdybtAmt() {
        return yzdybtAmt;
    }

    public void setYzdybtAmt(String yzdybtAmt) {
        this.yzdybtAmt = yzdybtAmt;
    }
    public BigDecimal getNbasicbenefit() {
        return nbasicbenefit;
    }

    public void setNbasicbenefit(BigDecimal nbasicbenefit) {
        this.nbasicbenefit = nbasicbenefit;
    }
    public BigDecimal getNusebenefit() {
        return nusebenefit;
    }

    public void setNusebenefit(BigDecimal nusebenefit) {
        this.nusebenefit = nusebenefit;
    }
    public BigDecimal getNcheckbenefit() {
        return ncheckbenefit;
    }

    public void setNcheckbenefit(BigDecimal ncheckbenefit) {
        this.ncheckbenefit = ncheckbenefit;
    }
    public BigDecimal getNyzbenefit() {
        return nyzbenefit;
    }

    public void setNyzbenefit(BigDecimal nyzbenefit) {
        this.nyzbenefit = nyzbenefit;
    }
    public String getGwrule() {
        return gwrule;
    }

    public void setGwrule(String gwrule) {
        this.gwrule = gwrule;
    }
    public String getNgwbenefit() {
        return ngwbenefit;
    }

    public void setNgwbenefit(String ngwbenefit) {
        this.ngwbenefit = ngwbenefit;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    
}
